@@ -14,7 +14,7 @@ module TomlRB
     def value
       year, mon, day = captures[:date_skeleton].first.value
       hour, min, sec, sec_frac = captures[:time_skeleton].first.value
-      usec = sec_frac.to_s.ljust(6, '0')
+      usec = sec_frac.to_s.ljust(6, "0")
 
       Time.local(year, mon, day, hour, min, sec, usec)
     end
@@ -23,16 +23,16 @@ module TomlRB
   module LocalDateParser
     def value
       year, mon, day = captures[:date_skeleton].first.value
-      Time.local(year,mon,day)
+      Time.local(year, mon, day)
     end
   end
 
   module LocalTimeParser
     def value
       hour, min, sec, sec_frac = captures[:time_skeleton].first.value
-      usec = sec_frac.to_s.ljust(6, '0')
+      usec = sec_frac.to_s.ljust(6, "0")
 
       Time.at(3600 * hour.to_i + 60 * min.to_i + sec.to_i, usec.to_i)
     end
   end
-end
\ No newline at end of file
+end
